# Engineering Feature

A specific type of engineering feature object is designed for each type of engineering feature.

## Create engineering features

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.EngineeringFeature.EngineeringFeature
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Classes

### Crack

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.Crack.Crack
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Fastener

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.Fastener.Fastener
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Inertia

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.Inertia.Inertia
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SpringDashpot

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.SpringDashpot.SpringDashpot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AssembledFastener

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.AssembledFastener.AssembledFastener
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ContourIntegral

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.ContourIntegral.ContourIntegral
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DebondVCCT

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.DebondVCCT.DebondVCCT
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DiscreteFastener

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.DiscreteFastener.DiscreteFastener
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EngineeringFeatureBase

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.EngineeringFeatureBase.EngineeringFeatureBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### HeatCapacitance

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.HeatCapacitance.HeatCapacitance
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### NonstructuralMass

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.NonstructuralMass.NonstructuralMass
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PointFastener

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.PointFastener.PointFastener
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PointMassInertia

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.PointMassInertia.PointMassInertia
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SpringDashpotToGround

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.SpringDashpotToGround.SpringDashpotToGround
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TwoPointSpringDashpot

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.TwoPointSpringDashpot.TwoPointSpringDashpot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### XFEMCrack

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.XFEMCrack.XFEMCrack
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
